/*
 * Copyright (C) 2023 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *
 */

package com.android.healthconnect.controller.dataentries.formatters

import android.content.Context
import android.health.connect.datatypes.BodyWaterMassRecord
import com.android.healthconnect.controller.dataentries.formatters.MassFormatter.formatA11yValue
import com.android.healthconnect.controller.dataentries.formatters.MassFormatter.formatValue
import com.android.healthconnect.controller.dataentries.formatters.shared.EntryFormatter
import com.android.healthconnect.controller.dataentries.units.UnitPreferences
import dagger.hilt.android.qualifiers.ApplicationContext
import javax.inject.Inject

/** Formatter for printing BodyWaterMassRecord data. */
class BodyWaterMassFormatter @Inject constructor(@ApplicationContext private val context: Context) :
    EntryFormatter<BodyWaterMassRecord>(context) {

    override suspend fun formatValue(
        record: BodyWaterMassRecord,
        unitPreferences: UnitPreferences
    ): String {
        return formatValue(context, record.bodyWaterMass, unitPreferences.getWeightUnit())
    }

    override suspend fun formatA11yValue(
        record: BodyWaterMassRecord,
        unitPreferences: UnitPreferences
    ): String {
        return formatA11yValue(context, record.bodyWaterMass, unitPreferences.getWeightUnit())
    }
}
