/*
 * Copyright (C) 2022 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.healthconnect.controller.service

import android.content.Context
import android.health.connect.HealthConnectManager
import android.os.Process
import dagger.Module
import dagger.Provides
import dagger.hilt.InstallIn
import dagger.hilt.android.qualifiers.ApplicationContext
import dagger.hilt.components.SingletonComponent

@Module
@InstallIn(SingletonComponent::class)
object HealthManagerModule {
    @Provides
    fun provideHealthConnectManager(@ApplicationContext context: Context): HealthConnectManager {
        val userHandle = Process.myUserHandle()
        val contextAsUser = context.createContextAsUser(userHandle, 0)
        return requireNotNull(contextAsUser.getSystemService(HealthConnectManager::class.java))
    }
}
